@@ -1,6 +1,7 @@
 from django.contrib.humanize.templatetags.humanize import intcomma
 from django.db.models import Count
-from django_datatables.columns import ColumnBase, CurrencyPenceColumn, CurrencyColumn, NoHeadingColumn, ColumnLink
+from django_datatables.columns import ColumnBase, CurrencyPenceColumn, CurrencyColumn, NoHeadingColumn, ColumnLink, \
+    ManyToManyColumn
 from django_datatables.helpers import get_url, DUMMY_ID
 
 
@@ -107,3 +108,16 @@ class RecordCountColumn(ColumnBase):
         if 'column_name' not in kwargs:
             kwargs['column_name'] = 'record_count'
         super().__init__(field, **kwargs)
+
+
+class ReportBuilderManyToManyColumn(ManyToManyColumn):
+
+    def __init__(self, *arg, **kwargs):
+        if not self.initialise(locals()):
+            return
+        super().__init__(*arg, **kwargs)
+        if self.model_path is not None:
+            self.field = 'id'
+
+    def row_result(self, data_dict, page_results):
+        return page_results['m2m' + self.column_name].get(data_dict[self.model_path + 'id'], self.blank)
