@@ -2,19 +2,21 @@ import re
 
 from django.apps import apps
 
-from advanced_report_builder.utils import get_field_details, get_report_builder_class
+from advanced_report_builder.field_utils import ReportBuilderFieldUtils
+from advanced_report_builder.utils import get_report_builder_class
 
 
-class DataMergeUtils:
+class DataMergeUtils(ReportBuilderFieldUtils):
     def get_menu_fields(self, base_model, report_builder_class,
                         menus=None, codes=None, code_prefix='', next_code_prefix='__',
                         previous_base_model=None, table=None):
 
         for report_builder_field in report_builder_class.fields:
-            django_field, col_type_override, columns, _ = get_field_details(base_model=base_model,
-                                                                            field=report_builder_field,
-                                                                            report_builder_class=report_builder_class,
-                                                                            table=table)
+            django_field, col_type_override, columns, _ = self.get_field_details(
+                base_model=base_model,
+                field=report_builder_field,
+                report_builder_class=report_builder_class,
+                table=table)
             for column in columns:
                 full_id = code_prefix + column.column_name
                 if menus is not None:
@@ -77,10 +79,10 @@ class DataMergeUtils:
         columns = set()
         column_map = {}
         for field in all_fields:
-            django_field, col_type_override, _, _ = get_field_details(base_model=base_model,
-                                                                      field=field,
-                                                                      report_builder_class=report_builder_class,
-                                                                      table=table)
+            django_field, col_type_override, _, _ = self.get_field_details(base_model=base_model,
+                                                                           field=field,
+                                                                           report_builder_class=report_builder_class,
+                                                                           table=table)
             if django_field is not None or isinstance(col_type_override.field, (list, tuple)):
                 if field not in columns and f'.{field}' not in columns:
                     columns.add('.' + field)
