@@ -32,31 +32,37 @@ ANNOTATION_VALUE_FUNCTIONS = {ANNOTATION_VALUE_YEAR: TruncYear,
                               ANNOTATION_VALUE_MONTH: TruncMonth,
                               ANNOTATION_VALUE_WEEK: TruncWeek,
                               ANNOTATION_VALUE_DAY: TruncDay}
+
 ANNOTATION_CHART_SCALE = {ANNOTATION_VALUE_YEAR: 'year',
                           ANNOTATION_VALUE_QUARTER: 'quarter',
                           ANNOTATION_VALUE_MONTH: 'month',
                           ANNOTATION_VALUE_WEEK: 'week',
                           ANNOTATION_VALUE_DAY: 'day'}
 
+GENERATE_SERIES_INTERVALS = {ANNOTATION_VALUE_YEAR: '1 year',
+                             ANNOTATION_VALUE_QUARTER: '3 month',
+                             ANNOTATION_VALUE_MONTH: '1 month',
+                             ANNOTATION_VALUE_WEEK: '1 week',
+                             ANNOTATION_VALUE_DAY: '1 day'}
 
 ANNOTATION_CHOICE_SUM = 1
-ANNOTATION_CHOICE_MAX = 2
-ANNOTATION_CHOICE_MIN = 3
+ANNOTATION_CHOICE_MAXIMUM = 2
+ANNOTATION_CHOICE_MINIMUM = 3
 ANNOTATION_CHOICE_COUNT = 4
-ANNOTATION_CHOICE_AVG = 5
+ANNOTATION_CHOICE_AVERAGE_SUM_FROM_COUNT = 5
 
 
 ANNOTATIONS_CHOICES = [(ANNOTATION_CHOICE_SUM, 'Sum'),
-                       (ANNOTATION_CHOICE_MAX, 'Max'),
-                       (ANNOTATION_CHOICE_MIN, 'Min'),
+                       (ANNOTATION_CHOICE_MAXIMUM, 'Maximum'),
+                       (ANNOTATION_CHOICE_MINIMUM, 'Minimum'),
                        (ANNOTATION_CHOICE_COUNT, 'Count'),
-                       (ANNOTATION_CHOICE_AVG, 'Avg')]
+                       (ANNOTATION_CHOICE_AVERAGE_SUM_FROM_COUNT, 'Average Sum from Count')]
 
 ANNOTATION_FUNCTIONS = {ANNOTATION_CHOICE_SUM: Sum,
-                        ANNOTATION_CHOICE_MAX: Max,
-                        ANNOTATION_CHOICE_MIN: Min,
+                        ANNOTATION_CHOICE_MAXIMUM: Max,
+                        ANNOTATION_CHOICE_MINIMUM: Min,
                         ANNOTATION_CHOICE_COUNT: Count,
-                        ANNOTATION_CHOICE_AVG: Avg}
+                        ANNOTATION_CHOICE_AVERAGE_SUM_FROM_COUNT: Avg}
 
 DATE_FORMAT_TYPE_DD_MM_YY_SLASH = 1
 DATE_FORMAT_TYPE_DD_MM_YYYY_SLASH = 2
