@@ -4,7 +4,8 @@ from advanced_report_builder.views.bar_charts import BarChartModal, BarChartFiel
     BarChartBreakdownFieldModal
 from advanced_report_builder.views.custom import CustomModal
 from advanced_report_builder.views.dashboard import DashboardReportModal, DashboardModal, DashboardAddReportModal
-from advanced_report_builder.views.datatables.modal import TableModal, TableFieldModal, TablePivotModal, TableQueryModal
+from advanced_report_builder.views.datatables.modal import TableModal, TableFieldModal, TablePivotModal
+from advanced_report_builder.views.query_modal.modal import QueryModal, QueryOrderModal
 from advanced_report_builder.views.funnel_charts import FunnelChartModal, FunnelChartFieldModal
 from advanced_report_builder.views.kanban import KanbanModal, KanbanLaneModal, KanbanLaneDuplicateModal, \
     KanbanDescriptionModal, KanbanDescriptionDuplicateModal
@@ -19,10 +20,13 @@ app_name = 'advanced_report_builder'
 
 
 urlpatterns = [
+
+    path('query/modal/query/<str:slug>', QueryModal.as_view(), name='query_modal'),
+    path('query/modal/query/order/<str:slug>', QueryOrderModal.as_view(), name='query_order_modal'),
+
     path('table/modal/<str:slug>/', TableModal.as_view(), name='table_modal'),
     path('table/modal/field/<str:slug>/', TableFieldModal.as_view(), name='table_field_modal'),
     path('table/modal/pivot/<str:slug>/', TablePivotModal.as_view(), name='table_pivot_modal'),
-    path('table/modal/query/<str:slug>', TableQueryModal.as_view(), name='table_query_modal'),
 
     path('single-value/modal/<str:slug>/', SingleValueModal.as_view(), name='single_value_modal'),
     path('single-value/modal/field/<str:slug>/', SingleValueTableFieldModal.as_view(), name='single_value_field_modal'),
