@@ -20,7 +20,7 @@ from advanced_report_builder.exceptions import ReportError
 from advanced_report_builder.globals import NUMBER_FIELDS, ANNOTATION_CHOICE_SUM, \
     ANNOTATION_CHOICE_AVERAGE_SUM_FROM_COUNT
 from advanced_report_builder.models import SingleValueReport, ReportType
-from advanced_report_builder.utils import get_field_details, get_report_builder_class
+from advanced_report_builder.utils import get_report_builder_class
 from advanced_report_builder.variable_date import VariableDate
 from advanced_report_builder.views.charts_base import ChartBaseView
 from advanced_report_builder.views.datatables.modal import TableFieldModal, TableFieldForm
@@ -40,13 +40,13 @@ class SingleValueView(ChartBaseView):
 
     def _process_aggregations(self, fields, aggregations_type=ANNOTATION_CHOICE_SUM, divider=None):
         field = self.chart_report.field
-        base_model = self.chart_report.get_base_modal()
+        base_model = self.chart_report.get_base_model()
         report_builder_class = get_report_builder_class(model=base_model,
                                                         report_type=self.chart_report.report_type)
 
-        django_field, col_type_override, _, _ = get_field_details(base_model=base_model,
-                                                                  field=field,
-                                                                  report_builder_class=report_builder_class)
+        django_field, col_type_override, _, _ = self.get_field_details(base_model=base_model,
+                                                                       field=field,
+                                                                       report_builder_class=report_builder_class)
 
         if (isinstance(django_field, NUMBER_FIELDS) or
                 col_type_override is not None and col_type_override.annotations):
@@ -139,11 +139,11 @@ class SingleValueView(ChartBaseView):
     def _process_percentage(self, fields):
         denominator_field = self.chart_report.field
         numerator_field = self.chart_report.numerator
-        base_model = self.chart_report.get_base_modal()
+        base_model = self.chart_report.get_base_model()
         report_builder_class = get_report_builder_class(model=base_model,
                                                         report_type=self.chart_report.report_type)
 
-        deno_django_field, denominator_col_type_override, _, _ = get_field_details(
+        deno_django_field, denominator_col_type_override, _, _ = self.get_field_details(
             base_model=base_model,
             field=denominator_field,
             report_builder_class=report_builder_class)
@@ -151,7 +151,7 @@ class SingleValueView(ChartBaseView):
                 (denominator_col_type_override is not None and not denominator_col_type_override.annotations)):
             raise ReportError('denominator is not a number field')
 
-        num_django_field, numerator_col_type_override, _, _ = get_field_details(
+        num_django_field, numerator_col_type_override, _, _ = self.get_field_details(
             base_model=base_model,
             field=denominator_field,
             report_builder_class=report_builder_class)
@@ -427,7 +427,7 @@ class SingleValueShowBreakdownModal(TableUtilsMixin, Modal):
         single_value_report = get_object_or_404(SingleValueReport, pk=self.slug['pk'])
         self.kwargs['enable_links'] = self.slug['enable_links'] == 'True'
         self.table_report = single_value_report
-        base_model = single_value_report.get_base_modal()
+        base_model = single_value_report.get_base_model()
         table = self.add_table(base_model=base_model)
         table.extra_filters = self.extra_filters
         table_fields = single_value_report.breakdown_fields
